from setuptools import setup

setup(
    name="snipprcomparison",
    version="0.0.1",
    author="Joshua Isanan",
    author_email="joshuaisanan@gmail.com",
    description="A package used to compare two snippets of code.",
    url="https://github.com/Zeshiba/snipprcomparison",
    packages=['snipprcomparison'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)